#!/usr/bin/env python

import logging
import logging.handlers
import metamako
import os
import sh
import sys

from pkg_resources import parse_version


ADVISORY = "SA0041"
RELEASE_VER_WITH_FIX = "0.21.1"
STATUS_DIR = "/var/run/metamako/hotfix/"
STATUS_FILE = STATUS_DIR + ADVISORY

logger = logging.getLogger()
logger.addHandler(logging.handlers.SysLogHandler("/dev/log"))
logger.setLevel(logging.INFO)


def install():
    logger.info("Installing hotfix for advisory %s" % ADVISORY)
    current_version = parse_version(metamako.software_version())
    fixed_version = parse_version(RELEASE_VER_WITH_FIX)
    if current_version >= fixed_version:
        logger.info("Hotfix for advisory %s is not required for MOS versions newer than: %s"
                                                                    % (ADVISORY, RELEASE_VER_WITH_FIX))
        return 0

    sh.iptables("-A INPUT -p tcp -m tcpmss --mss 1:500 -j DROP".split())
    sh.ip6tables("-A INPUT -p tcp -m tcpmss --mss 1:500 -j DROP".split())
    sh.sysctl("-w net.ipv4.tcp_mtu_probing=0".split())

    sh.mkdir('-p', STATUS_DIR)
    sh.touch(STATUS_FILE)
    logger.info("Hotfix for advisory %s installed successfully" % ADVISORY)


def uninstall():
    logger.info("Uninstalling hotfix for advisory %s" % ADVISORY)

    if not os.path.isfile(STATUS_FILE):
        logger.info("Hotfix for advisory %s is not installed, nothing to do" % ADVISORY)
        return 0

    sh.iptables("-D INPUT -p tcp -m tcpmss --mss 1:500 -j DROP".split())
    sh.ip6tables("-D INPUT -p tcp -m tcpmss --mss 1:500 -j DROP".split())

    sh.rm('-f', STATUS_FILE)
    logger.info("Hotfix for advisory %s uninstalled successfully" % ADVISORY)


if __name__ == "__main__":
    if len(sys.argv) != 2:
        raise Exception("Please provide a single 'install' or 'uninstall' argument")

    if sys.argv[1] == "install":
        sys.exit(install())
    elif sys.argv[1] == "uninstall":
        sys.exit(uninstall())
    else:
        raise Exception("Please provide a single 'install' or 'uninstall' argument")
